@@ -25,8 +25,10 @@ OFC2 bar chart data:
     
     my $chart = Chart::OFC2->new(
         'title'  => 'Bar chart test',
-        'x_axis' => {
-            'labels' => [ 'Jan', 'Feb', 'Mar', 'Apr', 'May' ],
+        x_axis => {
+            labels => {
+                labels => [ 'Jan', 'Feb', 'Mar', 'Apr', 'May' ],
+            }
         },
     );
     
@@ -61,8 +63,9 @@ F<t/output/pie-data.json>, F<t/output/hbar-data.json> are the data files.
 use Moose;
 use Moose::Util::TypeConstraints;
 use MooseX::StrictConstructor;
+use MooseX::Aliases;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp::Clan 'croak';
 use JSON::XS qw();
@@ -85,13 +88,10 @@ use List::MoreUtils 'any';
     has 'elements'       => (is => 'rw', isa => 'ArrayRef', default => sub{[]}, lazy => 1);
     has 'extremes'       => (is => 'rw', isa => 'Chart::OFC2::Extremes',  default => sub { Chart::OFC2::Extremes->new() }, lazy => 1);
     has 'tooltip'        => (is => 'rw', isa => 'Chart::OFC2::ToolTip',);
+    has 'bg_colour'      => (is => 'rw', isa => 'Str',  default => 'f8f8d8', alias => 'bg_color' );
 
 =cut
 
-subtype 'Chart.OFC2.NaturalInt'
-    => as 'Int'
-    => where { $_ > 0 };
-
 has 'data_load_type' => (is => 'rw', isa => 'Str',  default => 'inline_js');
 has 'bootstrap'      => (is => 'rw', isa => 'Bool', default => '1');
 has 'title'          => (is => 'rw', isa => 'Chart::OFC2::Title', default => sub { Chart::OFC2::Title->new() }, lazy => 1, coerce  => 1);
@@ -101,8 +101,7 @@ has 'elements'       => (is => 'rw', isa => 'ArrayRef', default => sub{[]}, lazy
 has 'extremes'       => (is => 'rw', isa => 'Chart::OFC2::Extremes',  default => sub { Chart::OFC2::Extremes->new() }, lazy => 1);
 has '_json'          => (is => 'rw', isa => 'Object',  default => sub { JSON::XS->new->pretty(1)->convert_blessed(1) }, lazy => 1);
 has 'tooltip'        => (is => 'rw', isa => 'Chart::OFC2::ToolTip', coerce  => 1);
-has 'bg_colour'      => (is => 'rw', isa => 'Str',  default => 'f8f8d8');
-
+has 'bg_colour'      => (is => 'rw', isa => 'Str',  default => 'f8f8d8', alias => 'bg_color' );
 
 =head1 METHODS
 
@@ -326,6 +325,18 @@ sub smooth {
     return smoother_number($number, $axis_type);
 }
 
+=head2 bg_color()
+
+Same as bg_colour().
+
+=cut
+
+sub bg_color {
+    &bg_colour;
+}
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 
@@ -339,7 +350,7 @@ file in html every time you generate new data. Like C<"data.json?".time()>.
 
 =head1 SEE ALSO
 
-L<Chart::OFC>, L<http://teethgrinder.co.uk/open-flash-chart-2/>, L<http://svn.cle.sk/repos/pub/cpan/Chart-OFC2/trunk/>
+L<Chart::OFC>, L<http://teethgrinder.co.uk/open-flash-chart-2/>, L<http://github.com/jozef/chart-ofc2/>
 
 =head1 AUTHOR
 
@@ -359,6 +370,7 @@ order):
     John Goulah C<< <jgoulah@cpan.org> >>
     Noë Snaterse
     Adam J. Foxson C<< <atom@cpan.org> >>
+    Jeff Tam
 
 =head1 SUPPORT
 
