@@ -8,8 +8,10 @@ Chart::OFC2::Axis - OFC2 axis base module
 
     use Chart::OFC2::Axis;
     my $x_axis = Chart::OFC2::XAxis->new(
-        'labels' => [ 'Jan', 'Feb', 'Mar', 'Apr', 'May' ],
-    ),
+        labels => { 
+            labels => [ 'Jan', 'Feb', 'Mar', 'Apr', 'May' ] 
+        }
+    );
 
 =head1 DESCRIPTION
 
@@ -20,23 +22,25 @@ X or Y axis for OFC2.
 use Moose;
 use Moose::Util::TypeConstraints;
 use MooseX::StrictConstructor;
+use MooseX::Aliases;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Chart::OFC2;
 use Chart::OFC2::Labels;
+use Chart::OFC2::Types qw( PositiveInt ChartOFC2Labels );
 
 
 =head1 PROPERTIES
 
     has 'name'        => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
-    has 'labels'      => ( is => 'rw', isa => 'Chart::OFC2::Labels', coerce  => 1);
+    has 'labels'      => ( is => 'rw', isa => ChartOFC2Labels, coerce  => 1);
     has 'stroke'      => ( is => 'rw', isa => 'Int', );
-    has 'colour'      => ( is => 'rw', isa => 'Str',  );
+    has 'colour'      => ( is => 'rw', isa => 'Str', alias => 'color' );
     has 'offset'      => ( is => 'rw', isa => 'Bool', );
-    has 'grid_colour' => ( is => 'rw', isa => 'Str', );
-    has '3d'          => ( is => 'rw', isa => 'Bool', );
-    has 'steps'       => ( is => 'rw', isa => 'Int', );
+    has 'grid_colour' => ( is => 'rw', isa => 'Str', alias => 'grid_color');
+    has 'is3d'        => ( is => 'rw', isa => 'Bool', );
+    has 'steps'       => ( is => 'rw', isa => PositiveInt, );
     has 'visible'     => ( is => 'rw', isa => 'Bool',  );
     has 'min'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
     has 'max'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
@@ -51,13 +55,13 @@ coerce 'Chart::OFC2::YAxis'
     => via { Chart::OFC2::YAxis->new($_) };
 
 has 'name'        => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
-has 'labels'      => ( is => 'rw', isa => 'Chart::OFC2::Labels', coerce  => 1);
+has 'labels'      => ( is => 'rw', isa => ChartOFC2Labels, coerce  => 1);
 has 'stroke'      => ( is => 'rw', isa => 'Int', );
-has 'colour'      => ( is => 'rw', isa => 'Str',  );
+has 'colour'      => ( is => 'rw', isa => 'Str', alias => 'color' );
 has 'offset'      => ( is => 'rw', isa => 'Bool', );
-has 'grid_colour' => ( is => 'rw', isa => 'Str', );
-has '3d'          => ( is => 'rw', isa => 'Bool', );
-has 'steps'       => ( is => 'rw', isa => 'Chart.OFC2.NaturalInt', );
+has 'grid_colour' => ( is => 'rw', isa => 'Str', alias => 'grid_color');
+has 'is3d'        => ( is => 'rw', isa => 'Bool', );
+has 'steps'       => ( is => 'rw', isa => PositiveInt, );
 has 'visible'     => ( is => 'rw', isa => 'Bool',  );
 has 'min'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
 has 'max'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
@@ -73,13 +77,39 @@ Returns HashRef that is possible to give to C<encode_json()> function.
 sub TO_JSON {
     my ($self) = @_;
     
-    return {
+    my %json = (
         map  { my $v = $self->$_; (defined $v ? ($_ => $v) : ()) }
         grep { $_ ne 'name' }
         map  { $_->name } $self->meta->get_all_attributes
-    };
+    );
+    $json{'3d'} = delete $json{'is3d'}
+        if (exists $json{'is3d'});
+
+    return \%json;
 }
 
+=head2 color()
+
+Same as colour().
+
+=cut
+
+sub color {
+    &colour;
+}
+
+=head2 grid_color()
+
+Same as grid_colour().
+
+=cut
+
+sub grid_color {
+    &grid_colour;
+}
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 
